## 8.0.0.20241004 (2024-10-04)

Remove Pillow stubs (#12732)

## 8.0.0.20241002 (2024-10-02)

[stubsabot] Bump qrcode to 8.0.* (#12718)

Release: https://pypi.org/pypi/qrcode/8.0
Homepage: https://github.com/lincolnloop/python-qrcode
Repository: https://github.com/lincolnloop/python-qrcode
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/qrcode
Diff: https://github.com/lincolnloop/python-qrcode/compare/v7.4.2...v8.0

Stubsabot analysis of the diff between the two releases:
 - 2 public Python files have been added: `qrcode/compat/png.py`, `qrcode/tests/consts.py`.
 - 0 files included in typeshed's stubs have been deleted.
 - 12 files included in typeshed's stubs have been modified or renamed.
 - Total lines of Python code added: 669.
 - Total lines of Python code deleted: 727.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 7.4.0.20240921 (2024-09-21)

Complete coverage for the qrcode package (#12675)

## 7.4.0.20240408 (2024-04-08)

[qrcode] Add various annotations (#11726)

## 7.4.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

## 7.4.0.1 (2023-11-09)

Bump flake8-pyi to 23.11.0 (#10997)

## 7.4.0.0 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

Add stubs for qrcode (#10380)

